#ifdef USE_SMB_BRANCH
#define UNDEFINED		0x01
#define CHALLENGED		0x02
#define FAILED			0x04
#define SUCCESS			0x08
#define LOCATION_SERVERS	0x10
#define LOCATION_WORKGROUPS	0x20
#define LOCATION_SHARES		0x40
int
SMBLookup (GtkTreeView *treeview,unsigned char *servidor,
		GtkTreeIter *iter,int caso,
		char *pass);
#endif

